/**
 */
package de.mdelab.mlstorypatterns;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EStructuralFeature;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern Link</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A StoryPatternLink is matched to an instance of EStructuralFeature.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getFeature <em>Feature</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getLinkPositionConstraint <em>Link Position Constraint</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints <em>Outgoing Link Order Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints <em>Incoming Link Order Constraints</em>}</li>
 * </ul>
 * </p>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink()
 * @model
 * @generated
 */
public interface StoryPatternLink extends AbstractStoryPatternLink {
	/**
	 * Returns the value of the '<em><b>Feature</b></em>' reference. <!--
	 * begin-user-doc --> <!-- end-user-doc --> <!-- begin-model-doc --> The
	 * EStructuralFeature to match this link to. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Feature</em>' reference.
	 * @see #setFeature(EStructuralFeature)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_Feature()
	 * @model required="true"
	 * @generated
	 */
	EStructuralFeature getFeature();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.StoryPatternLink#getFeature
	 * <em>Feature</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Feature</em>' reference.
	 * @see #getFeature()
	 * @generated
	 */
	void setFeature(EStructuralFeature value);

	/**
	 * Returns the value of the '<em><b>Link Position Constraint</b></em>'
	 * attribute. The default value is <code>"UNCONSTRAINED"</code>. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.LinkPositionConstraintEnum}. <!--
	 * begin-user-doc --> <!-- end-user-doc --> <!-- begin-model-doc --> In case
	 * the feature is ordered, the link position constraint expresses an
	 * additional constraint on the position of the target object in the link.
	 * <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Link Position Constraint</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkPositionConstraintEnum
	 * @see #setLinkPositionConstraint(LinkPositionConstraintEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_LinkPositionConstraint()
	 * @model default="UNCONSTRAINED" required="true"
	 * @generated
	 */
	LinkPositionConstraintEnum getLinkPositionConstraint();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getLinkPositionConstraint <em>Link Position Constraint</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Link Position Constraint</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkPositionConstraintEnum
	 * @see #getLinkPositionConstraint()
	 * @generated
	 */
	void setLinkPositionConstraint(LinkPositionConstraintEnum value);

	/**
	 * Returns the value of the '<em><b>Outgoing Link Order Constraints</b></em>
	 * ' reference list. The list contents are of type
	 * {@link de.mdelab.mlstorypatterns.LinkOrderConstraint}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink
	 * <em>Predecessor Link</em>}'. <!-- begin-user-doc --> <!-- end-user-doc
	 * --> <!-- begin-model-doc --> The LinkOrderConstraints, for which this
	 * StoryPatternLink is the preceeding link. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Outgoing Link Order Constraints</em>'
	 *         reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_OutgoingLinkOrderConstraints()
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink
	 * @model opposite="predecessorLink" ordered="false"
	 * @generated
	 */
	EList<LinkOrderConstraint> getOutgoingLinkOrderConstraints();

	/**
	 * Returns the value of the '<em><b>Incoming Link Order Constraints</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlstorypatterns.LinkOrderConstraint}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}'.
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * The LinkOrderConstraints, for which this StoryPatternLink is the preceeding link.
	 * <!-- end-model-doc -->
	 * @return the value of the '<em>Incoming Link Order Constraints</em>' reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_IncomingLinkOrderConstraints()
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink
	 * @model opposite="successorLink" resolveProxies="false" ordered="false"
	 * @generated
	 */
	EList<LinkOrderConstraint> getIncomingLinkOrderConstraints();

} // StoryPatternLink
