/**
 */
package de.mdelab.mlstorypatterns;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlexpressions.MLExpression;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern Object</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A StoryPatternObject is matched to an EObject, when the StoryPattern is executed.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getBindingType <em>Binding Type</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getConstraints <em>Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getAssignmentExpression <em>Assignment Expression</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getAttributeAssignments <em>Attribute Assignments</em>}</li>
 * </ul>
 * </p>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject()
 * @model
 * @generated
 */
public interface StoryPatternObject extends AbstractStoryPatternObject {
	/**
	 * Returns the value of the '<em><b>Binding Type</b></em>' attribute. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.BindingTypeEnum}. <!-- begin-user-doc
	 * --> <!-- end-user-doc --> <!-- begin-model-doc --> The binding type
	 * specifies, whether an existing binding is used for this object or a new
	 * match has to be sought. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Binding Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.BindingTypeEnum
	 * @see #setBindingType(BindingTypeEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_BindingType()
	 * @model required="true"
	 * @generated
	 */
	BindingTypeEnum getBindingType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPatternObject#getBindingType <em>Binding Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Binding Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.BindingTypeEnum
	 * @see #getBindingType()
	 * @generated
	 */
	void setBindingType(BindingTypeEnum value);

	/**
	 * Returns the value of the '<em><b>Constraints</b></em>' containment
	 * reference list. The list contents are of type
	 * {@link de.mdelab.mlexpressions.MLExpression}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> Constraints express
	 * additional conditions that have to be fulfilled to match this object.
	 * <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Constraints</em>' containment reference
	 *         list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_Constraints()
	 * @model containment="true" ordered="false"
	 * @generated
	 */
	EList<MLExpression> getConstraints();

	/**
	 * Returns the value of the '<em><b>Assignment Expression</b></em>'
	 * containment reference. <!-- begin-user-doc --> <!-- end-user-doc --> <!--
	 * begin-model-doc --> An assignment expression has to return an object to
	 * which the StoryPatternObject is matched. The StoryPatternObject's binding
	 * type has to be 'BOUND'. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Assignment Expression</em>' containment
	 *         reference.
	 * @see #setAssignmentExpression(MLExpression)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_AssignmentExpression()
	 * @model containment="true"
	 * @generated
	 */
	MLExpression getAssignmentExpression();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.StoryPatternObject#getAssignmentExpression
	 * <em>Assignment Expression</em>}' containment reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Assignment Expression</em>'
	 *            containment reference.
	 * @see #getAssignmentExpression()
	 * @generated
	 */
	void setAssignmentExpression(MLExpression value);

	/**
	 * Returns the value of the '<em><b>Attribute Assignments</b></em>'
	 * containment reference list. The list contents are of type
	 * {@link de.mdelab.mlstorypatterns.AttributeAssignment}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlstorypatterns.AttributeAssignment#getStoryPatternObject
	 * <em>Story Pattern Object</em>}'. <!-- begin-user-doc --> <!--
	 * end-user-doc --> <!-- begin-model-doc --> Attribute assignments specify
	 * attribute values to set when the StoryPattern is applied. Attribute
	 * assignments are evaluated after matching the pattern but before applying
	 * it. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Attribute Assignments</em>' containment
	 *         reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_AttributeAssignments()
	 * @see de.mdelab.mlstorypatterns.AttributeAssignment#getStoryPatternObject
	 * @model opposite="storyPatternObject" containment="true" ordered="false"
	 * @generated
	 */
	EList<AttributeAssignment> getAttributeAssignments();

} // StoryPatternObject
